import type { UserInfo } from '../sdk/UserInfoSingleton/types';
/**
 * The entry point to use Datadog's Logs feature.
 */
export declare type DdLogsType = {
    /**
     * Send a log with debug level.
     * @param message: The message to send.
     * @param context: The additional context to send.
     */
    debug(...args: LogArguments | LogWithErrorArguments): Promise<void>;
    /**
     * Send a log with info level.
     * @param message: The message to send.
     * @param context: The additional context to send.
     */
    info(...args: LogArguments | LogWithErrorArguments): Promise<void>;
    /**
     * Send a log with warn level.
     * @param message: The message to send.
     * @param context: The additional context to send.
     */
    warn(...args: LogArguments | LogWithErrorArguments): Promise<void>;
    /**
     * Send a log with error level.
     * @param message: The message to send.
     * @param context: The additional context to send.
     */
    error(...args: LogArguments | LogWithErrorArguments): Promise<void>;
};
/**
 * Log input from developers
 */
export declare type RawLog = {
    message: string;
    context: object;
    status: LogStatus;
};
export declare type RawLogWithError = {
    message: string;
    errorKind: string;
    errorMessage: string;
    stacktrace: string;
    context: object;
    status: LogStatus;
};
/**
 * Log input for native SDKs
 */
export declare type NativeLog = {
    message: string;
    context: object;
};
export declare type NativeLogWithError = {
    message: string;
    errorKind: string;
    errorMessage: string;
    stacktrace: string;
    context: object;
};
export declare type LogStatus = 'debug' | 'info' | 'warn' | 'error';
export declare type LogEvent = {
    message: string;
    context: object;
    errorKind?: string;
    errorMessage?: string;
    stacktrace?: string;
    readonly status: LogStatus;
    readonly userInfo: UserInfo;
    readonly attributes?: object;
};
export declare type LogEventMapper = (logEvent: LogEvent) => LogEvent | null;
export declare type LogArguments = [message: string, context?: object];
export declare type LogWithErrorArguments = [
    message: string,
    errorKind?: string,
    errorMessage?: string,
    stacktrace?: string,
    context?: object
];
